@@ -50,28 +50,36 @@
 #'
 #' @examples
 #' data(fakedata)
-#' X <- cbind(fakedataset$x1,fakedataset$x2,fakedataset$x3)
+#' X <- cbind(fakedataset$x1, fakedataset$x2, fakedataset$x3)
 #'
-#' (MI <- MI.vec(x=X,W=W,alternative="greater",symmetrize=TRUE))
+#' (MI <- MI.vec(x = X, W = W, alternative = "greater", symmetrize = TRUE))
 #'
 #' @export
 
-MI.vec <- function(x,W,alternative="greater",symmetrize=TRUE){
+MI.vec <- function(x, W, alternative = "greater", symmetrize = TRUE) {
   # convert x to a matrix and save names (if provided)
   x <- as.matrix(x)
-  if(!is.null(colnames(x))) nams <- colnames(x)
+  if (!is.null(colnames(x))) {
+    nams <- colnames(x)
+  }
 
   #####
   # Input
   # Checks
   #####
-  if(0 %in% apply(x,2,sd)) warning("Constant term detected in x")
-  if(!any(class(W) %in% c("matrix","Matrix","data.frame"))){
+  if (0 %in% apply(x, 2, sd)) {
+    warning("Constant term detected in x")
+  }
+  if (!any(class(W) %in% c("matrix", "Matrix", "data.frame"))) {
     stop("W must be of class 'matrix' or 'data.frame'")
   }
-  if(any(class(W)!="matrix")) W <- as.matrix(W)
-  if(anyNA(x) | anyNA(W)) stop("Missing values detected")
-  if(!(alternative %in% c("greater","lower", "two.sided"))){
+  if (any(class(W) != "matrix")) {
+    W <- as.matrix(W)
+  }
+  if (anyNA(x) | anyNA(W)) {
+    stop("Missing values detected")
+  }
+  if (!(alternative %in% c("greater", "lower", "two.sided"))) {
     stop("Invalid input: 'alternative' must be either 'greater',
          'lower', or 'two.sided'")
   }
@@ -80,37 +88,41 @@ MI.vec <- function(x,W,alternative="greater",symmetrize=TRUE){
   # Additional
   # Variables
   #####
-  if(symmetrize) W <- .5 * (W + t(W))
+  if (symmetrize) {
+    W <- .5 * (W + t(W))
+  }
   nx <- ncol(x)
   n <- nrow(W)
-  df <- n-1 # only one variable considered at a time
-  S0 <- t(rep(1,n)) %*% W %*% rep(1,n)
-  S1 <- sum((W*W)+(W*t(W)))
-  S2 <- sum((rowSums(W)+colSums(W))^2)
+  df <- n - 1 # only one variable considered at a time
+  S0 <- t(rep(1, n)) %*% W %*% rep(1, n)
+  S1 <- sum((W * W) + (W * t(W)))
+  S2 <- sum((rowSums(W) + colSums(W))^2)
 
   # projection matrix M
-  M <- diag(n)-rep(1,n)%*%t(rep(1,n))/n
+  M <- diag(n) - rep(1, n) %*% t(rep(1, n)) / n
   MWM <- M %*% W %*% M
 
   #####
   # Output
   #####
-  out <- data.frame(matrix(NA,nrow=nx,ncol=6))
-  colnames(out) <- c("I","EI","VarI","zI","pI","")
-  for(i in 1:nx){
+  out <- data.frame(matrix(NA, nrow = nx, ncol = 6))
+  colnames(out) <- c("I", "EI", "VarI", "zI", "pI", "")
+  for (i in 1:nx) {
     # observed
-    out[i,"I"] <- (n/S0) * t(x[,i]) %*% MWM %*% x[,i] / crossprod(x[,i],M) %*% x[,i]
+    out[i, "I"] <- (n / S0) * t(x[, i]) %*% MWM %*% x[, i] / crossprod(x[, i], M) %*% x[, i]
     # expected
-    out[i,"EI"] <- -1/(n-1)
+    out[i, "EI"] <- -1 / (n - 1)
     # variance (normality assumption)
-    out[i,"VarI"] <- ((n^2*S1 - n*S2 + 3*S0^2) / (S0^2 * (n^2-1))) - out[i,"EI"]^2
+    out[i, "VarI"] <- ((n^2 * S1 - n * S2 + 3 * S0^2) / (S0^2 * (n^2 - 1))) - out[i, "EI"]^2
     # test statistic
-    out[i,"zI"] <- (out[i,"I"]-out[i,"EI"])/sqrt(out[i,"VarI"])
+    out[i, "zI"] <- (out[i, "I"] - out[i, "EI"]) / sqrt(out[i, "VarI"])
     # pI
-    out[i,"pI"] <- pfunc(z=out[i,"zI"],alternative=alternative)
-    out[i,6] <- star(p=out[i,"pI"])
+    out[i, "pI"] <- pfunc(z = out[i, "zI"], alternative = alternative)
+    out[i, 6] <- star(p = out[i, "pI"])
+  }
+  if (!is.null(colnames(x))) {
+    rownames(out) <- nams
   }
-  if(!is.null(colnames(x))) rownames(out) <- nams
 
   return(out)
 }
